@@ -27,6 +27,17 @@ class CairoVisitor (Visitor):
 			ctx.translate (-group.GetTranslation () [0],
 						-group.GetTranslation () [1])
 
+	def VisitPath (self, path, ctx = None):
+		if path.GetStroke () is None:
+			return
+
+		self._ApplyStroke (path.GetStroke (), ctx)
+		ctx.move_to (path.GetPoints () [0].x, path.GetPoints () [0].y)
+
+		for p in path.GetPoints () [1:]:
+			ctx.line_to (p.x, p.y)
+		ctx.stroke ()
+
 	def VisitLine (self, line, ctx = None):
 		if line.GetStroke () is None:
 			return
@@ -107,6 +118,17 @@ class CairoVisitor (Visitor):
 
 		ctx.new_path ()
 
+	def VisitImage (self, image, ctx=None):
+		fill = cairo.ImageSurface.create_from_png (image.GetFilename ())
+		w = fill.get_width ()
+		h = fill.get_height ()
+
+		with ctx:
+			ctx.translate (image.GetPosition ().x, image.GetPosition ().y)
+			ctx.scale (image.GetSize ().x / w, image.GetSize ().y / h)
+			ctx.set_source_surface (fill, 0, 0)
+			ctx.paint ()
+
 	def VisitCircle (self, circle, ctx=None):
 		if circle.GetFill () is None and circle.GetStroke () is None:
 			return
